@@ -1,3 +1,4 @@
+import json
 
 from loguru import logger
 from uuid import uuid4
@@ -65,18 +66,26 @@ class Agent:
                 }
             )
 
-        response = await self.client.responses.create(
-            model=self.model,
-            input=gpt_messages,
-            temperature=self.temperature,
-            top_p=self.top_p,
-            tools=tools_schema,
-            tool_choice="auto"
-        )
+        try:
+            response = await self.client.responses.create(
+                model=self.model,
+                input=gpt_messages,
+                temperature=self.temperature,
+                top_p=self.top_p,
+                tools=tools_schema,
+                tool_choice="auto"
+            )
+
+        except Exception as err:
+            self.log.debug(json.dumps(gpt_messages, indent=2, ensure_ascii=False))
+            self.log.debug(json.dumps(tools_schema, indent=2, ensure_ascii=False))
+
+            raise err
 
         response_types = []
         for i in response.output:
-            if i.__class__ in response_types:
+            if i.__class__ not in [ResponseFunctionToolCall, ResponseOutputMessage]:
+                self.log.warning(f"Unsupported response type -> {i.__class__}")
                 continue
 
             response_types.append(i.__class__)
@@ -119,9 +128,6 @@ class Agent:
                 ])
             )
 
-        else:
-            raise TypeError(f"Unsupported response type -> {response_types[0]}")
-
     async def generate(self, chat: Chat) -> AgentResponse:
         try:
             return await self.__generate(chat)
