@@ -4,13 +4,10 @@ from loguru import logger as log
 
 from AgentService.agent import Agent
 from AgentService.types.agent_tool import AgentTool
-from AgentService.connector import AgentConnector
 from AgentService.config import Config
 from AgentService.db import Db
 from AgentService.app import start_app
 
-from AgentService.agent.file_search import search_in_files
-
 
 @click.group()
 def group():
